Work order

### Quote

### Details for quote number 00666

Description: Test equipment

Equipment: Description

Estimated start: 01/01/13

Estimated finish: 01/05/13

Estimated cost: $299.00

### Client details

Name: Client

Code | Item | Quantity | Price | Total
| Description | 1 | $10.00 | $10.00
Total: | $10.00

Details:

    This is the defect detected

Client signature
Client
Responsible signature
Quote responsible